@@ -104,3 +104,24 @@ class LoadMasterParameterError(Exception):
     def __init__(self, lm, parameters):
         msg = get_parameter_message(lm, parameters)
         super(LoadMasterParameterError, self).__init__(msg)
+
+
+class VirtualServiceMissingLoadmasterInfo(Exception):
+    def __init__(self, param):
+        msg = ("Virtual service is missing the LoadMaster parameter "
+               "'{}'").format(param)
+        super(VirtualServiceMissingLoadmasterInfo, self).__init__(msg)
+
+
+class RealServerMissingLoadmasterInfo(Exception):
+    def __init__(self, param):
+        msg = ("Virtual service is missing the LoadMaster parameter "
+               "'{}'").format(param)
+        super(RealServerMissingLoadmasterInfo, self).__init__(msg)
+
+
+class RealServerMissingVirtualServiceInfo(Exception):
+    def __init__(self, param):
+        msg = ("Virtual service is missing the LoadMaster parameter "
+               "'{}'").format(param)
+        super(RealServerMissingVirtualServiceInfo, self).__init__(msg)
